@@ -105,7 +105,7 @@ def logm(a: Numeric):
 
 
 @dispatch
-def cholesky(a: Numeric):
+def _cholesky(a: Numeric):
     return anp.linalg.cholesky(a)
 
 
