@@ -87,7 +87,7 @@ def logm(a: Numeric):
 
 
 @dispatch
-def cholesky(a: Numeric):
+def _cholesky(a: Numeric):
     return jnp.linalg.cholesky(a)
 
 
