@@ -17,6 +17,7 @@ __all__ = [
     "svd",
     "solve",
     "inv",
+    "pinv",
     "det",
     "logdet",
     "expm",
@@ -173,6 +174,24 @@ def inv(a):  # pragma: no cover
     """
 
 
+@dispatch
+def pinv(a):  # pragma: no cover
+    """Compute the pseudo-inverse of `a`.
+
+    Args:
+        a (tensor): Matrix to compute pseudo-inverse of.
+
+    Returns:
+        tensor: Pseudo-inverse of `a`.
+    """
+    if B.shape(a, -2) >= B.shape(a, -1):
+        chol = B.chol(B.matmul(a, a, tr_a=True))
+        return B.cholsolve(chol, B.transpose(a))
+    else:
+        chol = B.chol(B.matmul(a, a, tr_b=True))
+        return B.transpose(B.cholsolve(chol, a))
+
+
 @dispatch
 @abstract()
 def det(a):  # pragma: no cover
@@ -226,9 +245,9 @@ def logm(a):  # pragma: no cover
 
 
 @dispatch
-@abstract()
-def cholesky(a: Numeric):  # pragma: no cover
-    """Compute the Cholesky decomposition.
+def cholesky(a: Numeric):
+    """Compute the Cholesky decomposition. The matrix will automatically be regularised
+    because computing the decomposition.
 
     Args:
         a (tensor): Matrix to decompose.
@@ -236,11 +255,18 @@ def cholesky(a: Numeric):  # pragma: no cover
     Returns:
         tensor: Cholesky decomposition.
     """
+    return _cholesky(reg(a))
 
 
 chol = cholesky  #: Shorthand for `cholesky`.
 
 
+@dispatch
+@abstract()
+def _cholesky(a: Numeric):  # pragma: no cover
+    pass
+
+
 @dispatch
 @abstract(promote=2)
 def cholesky_solve(a, b):  # pragma: no cover
@@ -590,9 +616,8 @@ def block_diag(element: Numeric, *elements: Numeric):
                 B.zeros(dtype, shape[0], cols_built),
                 element,
                 B.zeros(dtype, shape[0], total_cols - cols_built - shape[1]),
-                axis=1
+                axis=1,
             )
         )
         cols_built += shape[1]
     return B.concat(*rows, axis=0)
-
