@@ -216,6 +216,11 @@ def sum(a: Numeric, axis=None, squeeze=True):
     return np.sum(a, axis=axis, keepdims=not squeeze)
 
 
+@dispatch
+def prod(a: Numeric, axis=None, squeeze=True):
+    return np.prod(a, axis=axis, keepdims=not squeeze)
+
+
 @dispatch
 def mean(a: Numeric, axis=None, squeeze=True):
     return np.mean(a, axis=axis, keepdims=not squeeze)
