@@ -96,7 +96,7 @@ def logm(a: Numeric):
 
 
 @dispatch
-def cholesky(a: Numeric):
+def _cholesky(a: Numeric):
     return tf.linalg.cholesky(a)
 
 
