@@ -92,7 +92,7 @@ def logm(a: Numeric):
 
 
 @dispatch
-def cholesky(a: Numeric):
+def _cholesky(a: Numeric):
     return torch.linalg.cholesky(a)
 
 
