@@ -21,6 +21,11 @@ def squeeze(a: Numeric):
     return torch.squeeze(a)
 
 
+@dispatch
+def broadcast_to(a: Numeric, *shape: Int):
+    return torch.broadcast_to(a, shape)
+
+
 @dispatch
 def diag(a: Numeric):
     return torch.diag(a)
